==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/aa-ER/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'crwdns1486:0crwdne1486:0',
    'manage'                    => 'crwdns6501:0crwdne6501:0',
    'field'		                => 'crwdns1487:0crwdne1487:0',
    'about_fieldsets_title'		=> 'crwdns1488:0crwdne1488:0',
    'about_fieldsets_text'		=> 'crwdns6503:0crwdne6503:0',
    'custom_format'             => 'crwdns6505:0crwdne6505:0',
    'encrypt_field'      	        => 'crwdns1792:0crwdne1792:0',
    'encrypt_field_help'      => 'crwdns1683:0crwdne1683:0',
    'encrypted'      	        => 'crwdns1695:0crwdne1695:0',
    'fieldset'      	        => 'crwdns1490:0crwdne1490:0',
    'qty_fields'      	      => 'crwdns1491:0crwdne1491:0',
    'fieldsets'      	        => 'crwdns1492:0crwdne1492:0',
    'fieldset_name'           => 'crwdns1493:0crwdne1493:0',
    'field_name'              => 'crwdns1494:0crwdne1494:0',
    'field_values'            => 'crwdns1684:0crwdne1684:0',
    'field_values_help'       => 'crwdns1793:0crwdne1793:0',
    'field_element'           => 'crwdns1495:0crwdne1495:0',
    'field_element_short'     => 'crwdns1496:0crwdne1496:0',
    'field_format'            => 'crwdns1497:0crwdne1497:0',
    'field_custom_format'     => 'crwdns1498:0crwdne1498:0',
    'field_custom_format_help'     => 'crwdns1971:0{15}crwdne1971:0',
    'required'   		          => 'crwdns1499:0crwdne1499:0',
    'req'   		              => 'crwdns1500:0crwdne1500:0',
    'used_by_models'   		    => 'crwdns1501:0crwdne1501:0',
    'order'   		            => 'crwdns1502:0crwdne1502:0',
    'create_fieldset'         => 'crwdns1503:0crwdne1503:0',
    'update_fieldset'         => 'crwdns11219:0crwdne11219:0',
    'fieldset_does_not_exist'   => 'crwdns11221:0crwdne11221:0',
    'fieldset_updated'         => 'crwdns11223:0crwdne11223:0',
    'create_fieldset_title' => 'crwdns6507:0crwdne6507:0',
    'create_field'            => 'crwdns1504:0crwdne1504:0',
    'create_field_title' => 'crwdns6509:0crwdne6509:0',
    'value_encrypted'      	        => 'crwdns1696:0crwdne1696:0',
    'show_in_email'     => 'crwdns11854:0crwdne11854:0',
    'show_in_email_short'     => 'crwdns11856:0crwdne11856:0',
    'help_text' => 'crwdns6511:0crwdne6511:0',
    'help_text_description' => 'crwdns6513:0crwdne6513:0',
    'about_custom_fields_title' => 'crwdns6515:0crwdne6515:0',
    'about_custom_fields_text' => 'crwdns6517:0crwdne6517:0',
    'add_field_to_fieldset' => 'crwdns6519:0crwdne6519:0',
    'make_optional' => 'crwdns6521:0crwdne6521:0',
    'make_required' => 'crwdns6523:0crwdne6523:0',
    'reorder' => 'crwdns6525:0crwdne6525:0',
    'db_field' => 'crwdns6527:0crwdne6527:0',
    'db_convert_warning' => 'crwdns10494:0crwdne10494:0',
    'is_unique' => 'crwdns6766:0crwdne6766:0',
    'unique' => 'crwdns6768:0crwdne6768:0',
    'display_in_user_view' => 'crwdns11207:0crwdne11207:0',
    'display_in_user_view_table' => 'crwdns11209:0crwdne11209:0',
    'auto_add_to_fieldsets' => 'crwdns11593:0crwdne11593:0',
    'add_to_preexisting_fieldsets' => 'crwdns11595:0crwdne11595:0',
    'show_in_listview' => 'crwdns11858:0crwdne11858:0',
    'show_in_listview_short' => 'crwdns11689:0crwdne11689:0',
    'show_in_requestable_list_short' => 'crwdns11860:0crwdne11860:0',
    'show_in_requestable_list' => 'crwdns11862:0crwdne11862:0',
    'encrypted_options' => 'crwdns11864:0crwdne11864:0',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/aa-ER/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'crwdns1486:0crwdne1486:0',
    'manage'                    => 'crwdns6501:0crwdne6501:0',
    'field'		                => 'crwdns1487:0crwdne1487:0',
    'about_fieldsets_title'		=> 'crwdns1488:0crwdne1488:0',
    'about_fieldsets_text'		=> 'crwdns6503:0crwdne6503:0',
    'custom_format'             => 'crwdns6505:0crwdne6505:0',
    'encrypt_field'      	        => 'crwdns1792:0crwdne1792:0',
    'encrypt_field_help'      => 'crwdns1683:0crwdne1683:0',
    'encrypted'      	        => 'crwdns1695:0crwdne1695:0',
    'fieldset'      	        => 'crwdns1490:0crwdne1490:0',
    'qty_fields'      	      => 'crwdns1491:0crwdne1491:0',
    'fieldsets'      	        => 'crwdns1492:0crwdne1492:0',
    'fieldset_name'           => 'crwdns1493:0crwdne1493:0',
    'field_name'              => 'crwdns1494:0crwdne1494:0',
    'field_values'            => 'crwdns1684:0crwdne1684:0',
    'field_values_help'       => 'crwdns1793:0crwdne1793:0',
    'field_element'           => 'crwdns1495:0crwdne1495:0',
    'field_element_short'     => 'crwdns1496:0crwdne1496:0',
    'field_format'            => 'crwdns1497:0crwdne1497:0',
    'field_custom_format'     => 'crwdns1498:0crwdne1498:0',
    'field_custom_format_help'     => 'crwdns1971:0{15}crwdne1971:0',
    'required'   		          => 'crwdns1499:0crwdne1499:0',
    'req'   		              => 'crwdns1500:0crwdne1500:0',
    'used_by_models'   		    => 'crwdns1501:0crwdne1501:0',
    'order'   		            => 'crwdns1502:0crwdne1502:0',
    'create_fieldset'         => 'crwdns1503:0crwdne1503:0',
    'update_fieldset'         => 'crwdns11219:0crwdne11219:0',
    'fieldset_does_not_exist'   => 'crwdns11221:0crwdne11221:0',
    'fieldset_updated'         => 'crwdns11223:0crwdne11223:0',
    'create_fieldset_title' => 'crwdns6507:0crwdne6507:0',
    'create_field'            => 'crwdns1504:0crwdne1504:0',
    'create_field_title' => 'crwdns6509:0crwdne6509:0',
    'value_encrypted'      	        => 'crwdns1696:0crwdne1696:0',
    'show_in_email'     => 'crwdns11854:0crwdne11854:0',
    'show_in_email_short' => 'crwdns12933:0crwdne12933:0',
    'help_text' => 'crwdns6511:0crwdne6511:0',
    'help_text_description' => 'crwdns6513:0crwdne6513:0',
    'about_custom_fields_title' => 'crwdns6515:0crwdne6515:0',
    'about_custom_fields_text' => 'crwdns6517:0crwdne6517:0',
    'add_field_to_fieldset' => 'crwdns6519:0crwdne6519:0',
    'make_optional' => 'crwdns6521:0crwdne6521:0',
    'make_required' => 'crwdns6523:0crwdne6523:0',
    'reorder' => 'crwdns6525:0crwdne6525:0',
    'db_field' => 'crwdns6527:0crwdne6527:0',
    'db_convert_warning' => 'crwdns10494:0crwdne10494:0',
    'is_unique' => 'crwdns6766:0crwdne6766:0',
    'unique' => 'crwdns6768:0crwdne6768:0',
    'display_in_user_view' => 'crwdns11207:0crwdne11207:0',
    'display_in_user_view_table' => 'crwdns11209:0crwdne11209:0',
    'auto_add_to_fieldsets' => 'crwdns11593:0crwdne11593:0',
    'add_to_preexisting_fieldsets' => 'crwdns11595:0crwdne11595:0',
    'show_in_listview' => 'crwdns11858:0crwdne11858:0',
    'show_in_listview_short' => 'crwdns11689:0crwdne11689:0',
    'show_in_requestable_list_short' => 'crwdns11860:0crwdne11860:0',
    'show_in_requestable_list' => 'crwdns11862:0crwdne11862:0',
    'encrypted_options' => 'crwdns11864:0crwdne11864:0',
    'display_checkin' => 'crwdns12929:0crwdne12929:0',
    'display_checkout' => 'crwdns12931:0crwdne12931:0',

];
